OC.L10N.register(
    "files",
    {
    "File could not be found" : "N'eo ket bet kavet ar restr",
    "Move or copy" : "Dilec'hiañ pe eilañ",
    "Download" : "Pellgargañ",
    "Delete" : "Lemel",
    "Tags" : "Klavioù",
    "Home" : "Degemer",
    "Close" : "Serriñ",
    "Could not create folder \"{dir}\"" : "Dibosupl eo krouiñ an teuliad \"{dir}\"",
    "This will stop your current uploads." : "Paouez a raio ho kasadennoù.",
    "Upload cancelled." : "Kasadenn nullet.",
    "Processing files …" : "Graet e vez war dro ar restroù ...",
    "…" : "...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Dibosupl eo kas {filename} evel emañ un teuliad pe ez eus 0 bytes anezhañ",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "N'eus ket trawalc'h a blas: o klask kas {size1} emaoc'h met n'eus nemet {size2} dieub",
    "Target folder \"{dir}\" does not exist any more" : "An teuliad \"{dir}\" n'eus ket anezhañ ken",
    "Not enough free space" : "N'eus ket trawalc'h a blas",
    "An unknown error has occurred" : "Ur fazi dizanv a zo bet",
    "Uploading …" : "O pellgas ...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} diwar {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "N'haller ket pellgas seurt restroù",
    "Target folder does not exist any more" : "An teuliad n'eus ket anezhañ ken",
    "Error when assembling chunks, status code {status}" : "Ur fazi zo bet en ur dolpañ ar blokoù, kod stad {status}",
    "Actions" : "Oberoù",
    "Rename" : "Adenvel",
    "Move" : "Diplasañ",
    "Copy" : "Eilañ",
    "Choose target folder" : "Dibab an teuliad moned",
    "Open" : "Digeriñ",
    "Could not load info for file \"{file}\"" : "Dibosupl eo kargañ titouroù ar restr \"{file}\"",
    "Files" : "Restroù",
    "Details" : "Munudoù",
    "Pending" : "O c'hortoz",
    "Unable to determine date" : "Dibosupl eo resisaat an deiziat",
    "This operation is forbidden" : "Difennet eo an ober-mañ",
    "This directory is unavailable, please check the logs or contact the administrator" : "N'eus ket tu da dizhout an teuliad-mañ, lennit al logoù pe kit e darempred gant ar merour",
    "Storage is temporarily not available" : "N'haller ket tizhout ar skor roadennoù evit ar poent",
    "Could not move \"{file}\", target exists" : "Dibosupl eo diblasañ \"{file}\", ar bukenn zo anezhi",
    "Could not move \"{file}\"" : "Dibosupl eo diblasañ \"{file}\"",
    "copy" : "eilañ",
    "Could not copy \"{file}\", target exists" : "Dibosupl eo eilañ \"{file}\", ar bukenn zo anezhi",
    "Could not copy \"{file}\"" : "Dibosupl eo eilañ \"{file}\"",
    "Copied {origin} inside {destination}" : "{origin} eilet e-barzh {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} ha {nbfiles} restr all eilet e-barzh {destination}",
    "{newName} already exists" : "{newName} zo anezhañ dija",
    "Could not rename \"{fileName}\", it does not exist any more" : "Dibosupl eo adenvel \"{fileName}\", n'eus ket anezhan ken",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "An anv \"{targetName}\" a zo implijet en teuliad \\\"{dir}\\\". Trugarez da zibab un anv all.",
    "Could not rename \"{fileName}\"" : "Dibosupl eo adenvel \"{fileName}\"",
    "Could not create file \"{file}\"" : "Dibosupl eo krouiñ ar restr \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Dibosupl eo krouiñ ar restr \"{file}\" peogwir ez eus anezhañ c'hoazh",
    "Could not create folder \"{dir}\" because it already exists" : "Dibosupl eo krouiñ an teuliad \"{dir}\" peogwir ez eus anezhañ c'hoazh",
    "Could not fetch file details \"{file}\"" : "Dibosupl eo adtapout munudoù ar restr \"{file}\"",
    "Error deleting file \"{fileName}\"." : "Ur fazi zo bet en ur ziverkañ ar restr \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Disoc'h ebet e teuliadoù all evit {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Lakait muioc'h eget daou arouez evit klask e teuliadoù all",
    "Name" : "Anv",
    "Size" : "Ment",
    "Modified" : "Cheñchet",
    "_%n folder_::_%n folders_" : ["%nteuliad","%n deuliad","teuliadoù zo","an darn vrasañ eus an teuliadoù","%n teuliad"],
    "_%n file_::_%n files_" : ["%n restr","%n restr","restroù zo","an darn vrasañ eus ar restroù","%n restr"],
    "{dirs} and {files}" : "{dirs} ha {files}",
    "_including %n hidden_::_including %n hidden_" : [" %n koachet en o zouez","%n goachet en o zouez","koachet en o zouez","koachet en o zouez","koachet en o zouez %n"],
    "_Uploading %n file_::_Uploading %n files_" : ["%n restr o vezañ karget","%n restr o vezañ karget","restroù zo o vezañ karget","an darn vrasañ eus ar restroù o vezañ karget","%n restr o vezañ karget"],
    "New" : "Nevez",
    "Select file range" : "Dibab un tachad restroù",
    "{used} of {quota} used" : "{used} diwar {quota} implijet",
    "{used} used" : "{used} implijet",
    "\"{name}\" is an invalid file name." : "N'eo ket \"{name}\" un anv restr aotreet.",
    "File name cannot be empty." : "N'hall ket anv ur restr bezañ goullo.",
    "\"/\" is not allowed inside a file name." : "N'eo ket aotreet \"/\" e anv ur restr.",
    "\"{name}\" is not an allowed filetype" : "N'eo ket \"{name}\" un doare restr aotreet",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Lec'h renkañ {owner} a zo kaji leun ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "Ho lec'h renkañ a zo kaji leun ({usedSpacePercent}%).",
    "View in folder" : "Diskwel en teuliad",
    "Path" : "Hent",
    "_%n byte_::_%n bytes_" : ["okted","okted","okted","okted","%n okted"],
    "Favorited" : "Lakaet evel pennroll",
    "Favorite" : "Pennrollañ",
    "New folder" : "Teuliad nevez",
    "Create new folder" : "Krouiñ un teuliad nevez",
    "Upload file" : "Pellgas ur restr",
    "Recent" : "Nevez",
    "Not favorited" : "N'eo ket bet pennrollet",
    "Remove from favorites" : "Diverkañañ eus ar pennrolloù",
    "Add to favorites" : "Ouzhpennañ er pennrolloù",
    "An error occurred while trying to update the tags" : "Ur fazi a zo bet en ur neveziñ ar c'hlavoù",
    "Added to favorites" : "Ouzhpennet er pennrolloù",
    "Removed from favorites" : "Diverket eus ar pennrolloù",
    "You added {file} to your favorites" : "Ouzhpennet ho peus {file} en ho pennrolloù",
    "You removed {file} from your favorites" : "Diverket ho peus {file} eus ho pennrolloù",
    "Favorites" : "Pennrolloù",
    "File changes" : "Cheñch ar restroù",
    "Created by {user}" : "Krouet gant {user}",
    "Changed by {user}" : "Cheñchet gant {user}",
    "Deleted by {user}" : "Dilemet gant {user}",
    "Restored by {user}" : "Adsavet gant {user}",
    "Renamed by {user}" : "Adanvet gant {user}",
    "Moved by {user}" : "Dilec'hiet gant {user}",
    "You created {file}" : "Krouet ho peus {file}",
    "You created an encrypted file in {file}" : "Ur restr sifret ho peus krouet e {file}",
    "{user} created {file}" : "{user} en.he deus krouet {file}",
    "{user} created an encrypted file in {file}" : " {file} a zo bet sifret gant {user}",
    "{file} was created in a public folder" : "{file} a zo bet krouet en un teuliad foran",
    "You changed {file}" : "Cheñchet ho peus {file}",
    "You changed an encrypted file in {file}" : "Ur restr sifret ho peus cheñchet e {file}",
    "{user} changed {file}" : "{file} a zo bet cheñchet gant {user}",
    "{user} changed an encrypted file in {file}" : "{file} a zo bet cheñchet gant {user}",
    "You deleted {file}" : "Dilemet ho peus {file}",
    "You deleted an encrypted file in {file}" : "Ur rest sufret e {file} ho peus dilemet.",
    "{user} deleted {file}" : "{user} en.he deus diverket {file}",
    "{user} deleted an encrypted file in {file}" : "Ur restr sifret e {file} a zo bet dilemet gant {user}",
    "You restored {file}" : "Adsavet ho peus {file}",
    "{user} restored {file}" : "{file} a zo bet adsavet gant {user}",
    "You renamed {oldfile} to {newfile}" : "Adanvet ho peus {oldfile} e {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{oldfile} a zo bet adanvet gant {user} e {newfile}",
    "You moved {oldfile} to {newfile}" : "Dilec'hiet ho peus {oldfile} e {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{oldfile} a zo bet dilec'hiet gant {user} e {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Ur restr a zo bet ouzhpennet pe ziverket en ho <strong>pennrolloù</strong>",
    "A file or folder has been <strong>changed</strong>" : "Ur restr pe un teuliad a zo bet <strong>cheñchet</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Unan eus ho restr pe teuliad karetañ a zo bet <strong>cheñchet</strong>",
    "Upload (max. %s)" : "Pellgas (max. %s)",
    "Accept" : "Asantiñ",
    "Reject" : "Nac'hañ",
    "Incoming ownership transfer from {user}" : "Treuzkas perc'henniezh a-berzh {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Asantiña rit {path} ?\n\nN. B. : Gallout a ra oberiadur an treuzkas padout betek 1 eur.",
    "Ownership transfer failed" : "C'hwitet eo bet an treuzkas perc'henniezh",
    "Your ownership transfer of {path} to {user} failed." : "Ho treuzkas perc'henniezh eus {path} da {user} en deus c'hwitet.",
    "The ownership transfer of {path} from {user} failed." : "An treuzkas perc'henniezh eus {path} da {user} en deus c'hwitet.",
    "Ownership transfer done" : "Treuzkas perc'hienniezh echu",
    "Your ownership transfer of {path} to {user} has completed." : "Ho treuzkas perc'henniezh eus {path} da {user} a zo echu.",
    "The ownership transfer of {path} from {user} has completed." : "An treuzkas perc'henniezh eus {path} da {user} a zo echu.",
    "in %s" : "e %s",
    "File Management" : "Meradur ar restr",
    "You don’t have permission to upload or create files here" : "N'och ket aotreet kas pe krouiñ restroù amañ",
    "Folder name" : "Anv teuliad",
    "Your storage is full, files can not be updated or synced anymore!" : "Leun eo ho skor stokañ. Ne c'hall ket ar restroù bezañ na nevezet na kempredet ken !",
    "Create" : "Krouiñ",
    "Transfer ownership of a file or folder" : "Treuzkas perc'henniezh ur restr pe un teuliad",
    "Choose file or folder to transfer" : "Dibabit ur restr pe un teuliad da dreuzkas",
    "Change" : "Cheñch",
    "New owner" : "Perc'henn nevez",
    "Choose a file or folder to transfer" : "Dibabit ur restr pe un teuliad da dreuzkas",
    "Transfer" : "Treuzkas",
    "Transfer {path} to {userid}" : "Treuzkas {path} da {userid}",
    "Invalid path selected" : "An hent dibabet n'eus ket anezhañ",
    "Unknown error" : "Fazi dizanv",
    "Ownership transfer request sent" : "Kaset eo bet ar goulenn treuzkas perc'henniezh",
    "No files in here" : "Restr ebet amañ",
    "Upload some content or sync with your devices!" : "Pellgas endalc'hoù pe gempredañ ho mekanikoù!",
    "Shared by link" : "Rannet dre liamm",
    "Shared" : "Rannet",
    "Show hidden files" : "Diskouez ar restroù koachet",
    "Additional settings" : "Stummoù ouzhpenn",
    "WebDAV" : "WebDAV",
    "Use this address to access your Files via WebDAV" : "Implijit ar chomlec'h-mañ evit tizhout ho restroù dre WebDAV",
    "Unable to change the favourite state of the file" : "Dibosupl eo cheñch stad pennroll ar restr",
    "Error while loading the file data" : "Ur fazi zo bet en ur gargañ roadennoùar restr",
    "Delete permanently" : "Lamet da viken",
    "Cancel" : "Arrest",
    "Filename" : "Anv restr",
    "No favorites yet" : "Pennroll ebet evit ar poent",
    "Files and folders you mark as favorite will show up here" : "Ar restroù ha teuliadoù ouzhpennet en ho pennrolloù a vo diskwelet amañ",
    "All files" : "An holl restroù",
    "No entries found in this folder" : "Disoc'h ebet en teuliad-mañ",
    "Select all" : "Dibab pep tra",
    "Upload too large" : "Re bonner eo ar gasadenn",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Ar restroù a glaskit pellgas a ya dreist d'ar vent vrasañ aotreet gant ar servijer mañ.",
    "Text file" : "Restr testenn",
    "New text file.txt" : "Restr testenn nevez rest.txt",
    "Copy direct link (only works for users who have access to this file/folder)" : "Eilañ al liamm eeun (nemet evit an implijourien aotreet da dizhout ar restr-mañ pe an teuliad-mañ)",
    "You can only favorite a single file or folder at a time" : "Ne c'hallit ouzhpennañ nemet ur pennroll teuliad pe restr en un taol.",
    "\"remote user\"" : "\"pell-implijer\"",
    "Search users" : "Klask implijourien",
    "Toggle grid view" : "Gweredekat/Diweredekat an diskwel roued",
    "Deleted files" : "Restroù dilemet",
    "Shares" : "Rannañ",
    "Shared with others" : "Rannet gant tud all",
    "Shared with you" : "Rannet ganeoc'h",
    "Deleted shares" : "Rannañ dilemet",
    "Pending shares" : "Rannañ o c'hortoz",
    "Choose" : "Dibab"
},
"nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
